CustomerLedgerEntry class
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- addedBy ↔ String?
-
getter/setter pair
- amount ↔ double?
-
getter/setter pair
- businessId ↔ String?
-
getter/setter pair
- customerId ↔ String?
-
getter/setter pair
- dateAdded ↔ DateTime?
-
getter/setter pair
- entryType ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pair
- isCancelled → bool
-
no setter
- isDebit → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
getter/setter pair
- transactionId ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited