DataItem class abstract
- Inheritance
-
- Object
- ChangeNotifier
- DataItem
- Annotations
-
- @IsoDateTimeConverter.new()
Constructors
Properties
- createdBy ↔ String?
-
getter/setter pair
- dateCreated ↔ DateTime?
-
getter/setter pair
- dateUpdated ↔ DateTime?
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- displayName ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- id ↔ String?
-
getter/setter pair
- itemSequence ↔ int?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → bool?
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited