AnyImageRepresentable class

Constructors

AnyImageRepresentable({required String name, double? width, double? height, Color? colour, IconData? iconData})
const

Properties

colour Color?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
iconData IconData?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

buildWidget() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited