BusinessSystemValue class

Annotations
  • @JsonSerializable.new()
  • @IsoDateTimeConverter.new()

Constructors

BusinessSystemValue({String? businessId, String? id, String? key, DateTime? lastUpdated, dynamic value, String? sectionKey})
BusinessSystemValue.fromJson(Map<String, dynamic> json)
factory

Properties

businessId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
key String?
getter/setter pair
lastUpdated DateTime?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sectionKey String?
getter/setter pair
value ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited