ReceiptData class

Annotations
  • @JsonSerializable.new()

Constructors

ReceiptData({bool displayCustomer = true, bool displayInstagramHandle = true, bool displaySeller = true, bool displayWhatsappLine = true, bool displayAddress = true, bool displayPhoneNumber = true, String? footer, String? header, })
ReceiptData.fromJson(Map<String, dynamic> json)
factory

Properties

displayAddress bool
getter/setter pair
displayCustomer bool
getter/setter pair
displayInstagramHandle bool
getter/setter pair
displayPhoneNumber bool
getter/setter pair
displaySeller bool
getter/setter pair
displayWhatsappLine bool
getter/setter pair
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
getter/setter pair
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited