StoreAddress class

Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @DateTimeConverter.new()

Constructors

StoreAddress({String? friendlyName, String? addressLine1, String? addressLine2, String? city, String? country, bool? enabled, StoreLocation? location, String? locationId, String? state, String? postalCode, String? placeId, String? id, bool? isPrimary})
StoreAddress.copy(StoreAddress source)
StoreAddress.fromJson(Map<String, dynamic> json)
factory

Properties

addressLine1 String?
getter/setter pair
addressLine2 String?
getter/setter pair
city String?
getter/setter pair
country String?
getter/setter pair
enabled bool?
getter/setter pair
friendlyName String?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String?
getter/setter pair
isPartiallyPopulated bool
no setter
isPopulated bool
no setter
isPrimary bool?
getter/setter pair
location StoreLocation?
getter/setter pair
locationId String?
getter/setter pair
placeId String?
getter/setter pair
postalCode String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toShortStringAddress() String
toString() String
A string representation of this object.
inherited
toStringAddress() String

Operators

operator ==(Object other) bool
The equality operator.
override