StoreLocation class

Constructors

StoreLocation({String? hash, double? latitude, double? longitude})
StoreLocation.copy(StoreLocation source)
StoreLocation.fromGeoFirePoint(GeoFirePoint point)
StoreLocation.fromJson(Map<String, dynamic> data)
factory

Properties

geopoint → GeoPoint?
no setter
hash String?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
latitude double?
getter/setter pair
longitude double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override