Address class
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- address → String
-
no setter
- address1 ↔ String?
-
getter/setter pair
- address2 ↔ String?
-
getter/setter pair
- city ↔ String?
-
getter/setter pair
- country ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAddressEmpty → bool
-
no setter
- location ↔ dynamic
-
getter/setter pair
- postalCode ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
getter/setter pair
Methods
-
copyWith(
{String? address1, String? address2, String? city, String? state, String? postalCode, String? country, dynamic location}) → Address -
formatAddress(
{String delimiter = ', '}) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited