Util class

Constructors

Util()

Properties

base32CodesDic Map<String, int>
getter/setter pair
encodeAuto String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sigfigHashLength List<int>
Significant Figure Hash Length
getter/setter pair

Methods

decode(String hashString) Map<String, double>
Decode a hashString into a pair of latitude and longitude. A map is returned with keys 'latitude', 'longitude','latitudeError','longitudeError'
decodeBbox(String hashString) List<double>
Decode Bounding box
encode(dynamic latitude, dynamic longitude, dynamic numberOfChars) String
Encode Create a geohash from latitude and longitude that is 'number of chars' long
neighbor(String hashString, dynamic direction) String
Neighbor
neighbors(String hashString) List<String>
Neighbors Returns all neighbors' hashstrings clockwise from north around to northwest 7 0 1 6 X 2 5 4 3
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

calcDistance(double lat1, double long1, double lat2, double long2) double
distance(Coordinates location1, Coordinates location2) double
setPrecision(double km) int